package com.digiwin.athena.app.ptc.service.paymentdetails;

import com.alibaba.nacos.common.utils.CollectionUtils;
import com.alibaba.nacos.common.utils.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.ptc.infra.entity.LimitCreditEntity;
import com.digiwin.athena.app.ptc.infra.entity.ReceivablesDetailEntity;
import com.digiwin.athena.app.ptc.infra.service.LimitCreditService;
import com.digiwin.athena.app.ptc.infra.service.ReceivablesDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.security.SecurityUtil;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @auther: zhenggl
 * @date: 2023/9/11
 */
@Service
@Log4j2
public class ReceivablesGetEAIService extends AbsEAIService {

    @Resource
    private ReceivablesDetailService receivablesDetailService;

    @Resource
    private LimitCreditService limitCreditService;

    @Override
    public String getServiceName() {
        return PaymentDetailsUtil.RECEIVABLES_GET;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {

        EAIRequest build = EAIRequest.build(messageBody);
        String startTime = build.getString("start_datetime");
        String endTime = build.getString("end_datetime");


        LambdaQueryWrapper<ReceivablesDetailEntity> lmq = new LambdaQueryWrapper<>();
        lmq.eq(ReceivablesDetailEntity::getTenantSid, SecurityUtil.getUserProfile().getTenantSid());
        if (StringUtils.isNotEmpty(startTime)&&StringUtils.isNotEmpty(endTime)){
            lmq.gt(ReceivablesDetailEntity::getCreateDate,startTime);
            lmq.le(ReceivablesDetailEntity::getCreateDate,endTime);
        }

        List<ReceivablesDetailEntity> list = receivablesDetailService.list(lmq);

        if (CollectionUtils.isEmpty(list)){
            return buildOK("query_result",list);
        }

        //查询限制额度
        List<String> customerNoList = list.stream().map(ReceivablesDetailEntity::getCustomerNo).collect(Collectors.toList());
        LambdaQueryWrapper<LimitCreditEntity> creditLmq = new LambdaQueryWrapper<>();
        creditLmq.in(LimitCreditEntity::getCustomerNo,customerNoList);
        List<LimitCreditEntity> limitCreditEntityList = limitCreditService.list(creditLmq);

        if (CollectionUtils.isNotEmpty(limitCreditEntityList)){
            for (ReceivablesDetailEntity receivablesDetailEntity : list) {
                for (LimitCreditEntity limitCreditEntity : limitCreditEntityList) {
                    if (Objects.nonNull(limitCreditEntity.getLimitAmount())&&receivablesDetailEntity.getCustomerNo().equals(limitCreditEntity.getCustomerNo())){
                        receivablesDetailEntity.setLimitAmount(limitCreditEntity.getLimitAmount());
                    }
                }
            }
        }


        return buildOK("query_result",list);
    }
}
